@@ -15,9 +15,10 @@ class GlueCredentials(Credentials):
     extra_jars: Optional[str] = None
     idle_timeout: int = 10
     query_timeout_in_seconds: int = 300
-    glue_version: Optional[str] = "2.0"
+    glue_version: Optional[str] = "3.0"
     security_configuration: Optional[str] = None
     connections: Optional[str] = None
+    conf: Optional[str] = None
     
     @property
     def type(self):
@@ -44,5 +45,6 @@ class GlueCredentials(Credentials):
             'query_timeout_in_seconds',
             'glue_version',
             'security_configuration',
-            'connections'
+            'connections',
+            'conf'
         ]
