@@ -18,13 +18,13 @@
   {% set tmp_relation = make_temp_relation(target_relation, '_tmp') %}
   {% set is_incremental = 'False' %}
 
-  {% if raw_strategy == 'merge' and file_format == 'hudi' %}
+  {% if file_format == 'hudi' %}
         {{ adapter.hudi_merge_table(target_relation, sql, unique_key, partition_by, custom_location) }}
         {% set build_sql = "select * from " + target_relation.schema + "." + target_relation.identifier %}
   {% else %}
       {% if strategy == 'insert_overwrite' and partition_by %}
         {% call statement() %}
-          set glue.sql.sources.partitionOverwriteMode = DYNAMIC
+          set spark.sql.sources.partitionOverwriteMode = DYNAMIC
         {% endcall %}
       {% endif %}
       {% if existing_relation_type is none %}
